@@ -22,6 +22,8 @@ Foundation, 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
 #include "driver.h"
 #include "nonposix.h"
 
+extern "C" const char *Version_string;
+
 #define DEFAULT_LINEWIDTH 40
 static int linewidth = DEFAULT_LINEWIDTH;
 
@@ -521,8 +523,8 @@ void dvi_printer::moveto(int h, int v)
 void dvi_printer::draw(int code, int *p, int np, const environment *env)
 {
   if (code == 'l') {
-    int x, y;
-    int height = 0, width;
+    int x = 0, y = 0;
+    int height = 0, width = 0;
     int thickness;
     if (line_thickness < 0)
       thickness = env->size*RES_7227*linewidth/1000;
@@ -863,7 +865,6 @@ int main(int argc, char **argv)
     switch(c) {
     case 'v':
       {
-	extern const char *Version_string;
 	printf("GNU grodvi (groff) version %s\n", Version_string);
 	exit(0);
 	break;
