@@ -25,7 +25,7 @@ Foundation, 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
 #include <osfcn.h>
 #else
 #include <fcntl.h>
-#ifndef _MSC_VER
+#ifdef HAVE_UNISTD_H
 #include <unistd.h>
 #endif
 #endif
