@@ -1,5 +1,5 @@
 // -*- C++ -*-
-/* Copyright (C) 1989, 1990, 1991, 1992 Free Software Foundation, Inc.
+/* Copyright (C) 1989, 1990, 1991, 1992, 2000 Free Software Foundation, Inc.
      Written by James Clark (jjc@jclark.com)
 
 This file is part of groff.
@@ -21,7 +21,7 @@ Foundation, 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
 #include "pic.h"
 #include "ptable.h"
 #include "object.h"
-#include "pic.tab.h"
+#include "pic_tab.h"
 
 declare_ptable(char)
 implement_ptable(char)
@@ -492,6 +492,7 @@ int lookup_keyword(const char *str, int len)
     { "same", SAME },
     { "sh", SH },
     { "sin", SIN },
+    { "solid", SOLID },
     { "spline", SPLINE },
     { "sprintf", SPRINTF },
     { "sqrt", SQRT },
