@@ -1,32 +1,37 @@
 #! /usr/bin/perl -P-
 # -*- Perl -*-
-#Copyright (C) 1989-2000 Free Software Foundation, Inc.
-#     Written by James Clark (jjc@jclark.com)
+# Copyright (C) 1989-2000 Free Software Foundation, Inc.
+#      Written by James Clark (jjc@jclark.com)
 #
-#This file is part of groff.
+# This file is part of groff.
 #
-#groff is free software; you can redistribute it and/or modify it under
-#the terms of the GNU General Public License as published by the Free
-#Software Foundation; either version 2, or (at your option) any later
-#version.
+# groff is free software; you can redistribute it and/or modify it under
+# the terms of the GNU General Public License as published by the Free
+# Software Foundation; either version 2, or (at your option) any later
+# version.
 #
-#groff is distributed in the hope that it will be useful, but WITHOUT ANY
-#WARRANTY; without even the implied warranty of MERCHANTABILITY or
-#FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
-#for more details.
+# groff is distributed in the hope that it will be useful, but WITHOUT ANY
+# WARRANTY; without even the implied warranty of MERCHANTABILITY or
+# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+# for more details.
 #
-#You should have received a copy of the GNU General Public License along
-#with groff; see the file COPYING.  If not, write to the Free Software
-#Foundation, 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+# You should have received a copy of the GNU General Public License along
+# with groff; see the file COPYING.  If not, write to the Free Software
+# Foundation, 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
 $prog = $0;
 $prog =~ s@.*/@@;
 
 do 'getopts.pl';
-do Getopts('e:sd:i:a:n');
+do Getopts('ve:sd:i:a:n');
+
+if ($opt_v) {
+    print "GNU afmtodit (groff) version @VERSION@\n";
+    exit 0;
+}
 
 if ($#ARGV != 2) {
-    die "Usage: $prog [-ns] [-d DESC] [-e encoding] [-i n] [-a angle] afmfile mapfile font\n";
+    die "Usage: $prog [-nsv] [-d DESC] [-e encoding] [-i n] [-a angle] afmfile mapfile font\n";
 }
 
 $afm = $ARGV[0];
